@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -368,6 +368,8 @@ typedef unsigned int SCIP_NLHDLR_METHOD; /**< nlhdlr methods bitflags */
 /** nonlinear handler under/overestimation callback
  *
  * The method tries to compute linear under- or overestimators of `expr` that are as tight as possible at a given point.
+ * Note that the cons_nonlinear handler adds an auxvar into a rowprep automatically after this callback.
+ * Therefore, the rowprep should only store the estimator in this callback.
  * If the value of the estimator in the solution is smaller (larger) than `targetvalue`
  * when underestimating (overestimating), then no estimator needs to be computed.
  * Note, that `targetvalue` can be infinite if any estimator will be accepted.
@@ -408,6 +410,34 @@ typedef unsigned int SCIP_NLHDLR_METHOD; /**< nlhdlr methods bitflags */
    SCIP_Bool*           success,         \
    SCIP_Bool*           addedbranchscores)
 
+/** nonlinear handler solution linearization callback
+ *
+ * The callback is called when a new feasible solution has been found.
+ * The nonlinear handler may add tight estimates on its nonlinear function to the cut pool of SCIP.
+ *
+ * \param[in] scip               SCIP main data structure
+ * \param[in] conshdlr           constraint handler
+ * \param[in] cons               a nonlinear constraint which includes expression
+ * \param[in] nlhdlr             nonlinear handler
+ * \param[in] expr               expression
+ * \param[in] nlhdlrexprdata     expression data of nonlinear handler
+ * \param[in] sol                solution that has been found
+ * \param[in] solisbest          whether solution is new best solution (incumbent)
+ * \param[in] overestimate       whether the expression needs is overestimated by the nlhdlr
+ * \param[in] underestimate      whether the expression needs is underestimated by the nlhdlr
+ */
+#define SCIP_DECL_NLHDLRSOLLINEARIZE(x) SCIP_RETCODE x (\
+   SCIP*                scip,            \
+   SCIP_CONSHDLR*       conshdlr,        \
+   SCIP_CONS*           cons,            \
+   SCIP_NLHDLR*         nlhdlr,          \
+   SCIP_EXPR*           expr,            \
+   SCIP_NLHDLREXPRDATA* nlhdlrexprdata,  \
+   SCIP_SOL*            sol,             \
+   SCIP_Bool            solisbest,       \
+   SCIP_Bool            overestimate,    \
+   SCIP_Bool            underestimate)
+
 typedef struct SCIP_Nlhdlr         SCIP_NLHDLR;          /**< nonlinear handler */
 typedef struct SCIP_NlhdlrData     SCIP_NLHDLRDATA;      /**< nonlinear handler data */
 typedef struct SCIP_NlhdlrExprData SCIP_NLHDLREXPRDATA;  /**< nonlinear handler data for a specific expression */
